@@ -7,12 +7,14 @@ def main():
 
   import sys
   from openapi_ts import generate_client
-  from moveread.pipelines.preprocess.api import manual_api
+  from moveread.pipelines.preprocess._api import api
 
-  app = manual_api(corr_api={}, val_api={}, sel_api={}) # type: ignore
+  app = api(corr_api={}, val_api={}, sel_api={}, images={}) # type: ignore
   spec = app.openapi()
   generate_client(spec, args.output, logstream=sys.stderr, args={
     '--client': '@hey-api/client-fetch',
+    '--services': '{ asClass: false }',
+    '--schemas': 'false'
   })
 
 if __name__ == '__main__':
